#
# spec file for package python-resampy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_with test
%else
%bcond_without test
%define psuffix -%{flavor}
%endif

Name:           python-resampy%{psuffix}
Version:        0.4.3
Release:        2.1
Summary:        Signal resampling in Python
License:        ISC
Group:          Development/Languages/Python
URL:            https://github.com/bmcfee/resampy
# The GitHub archive includes the tests
Source:         https://github.com/bmcfee/resampy/archive/refs/tags/%{version}.tar.gz#/resampy-%{version}-gh.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numba >= 0.53
Requires:       python-numpy >= 1.17
Suggests:       python-numpydoc
Suggests:       python-sphinx
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module resampy = %{version}}
BuildRequires:  %{python_module scipy >= 1.1}
%endif
%python_subpackages

%description
This package implements the band-limited sinc interpolation method
in Python for sampling rate conversion as described by:

Smith, Julius O. Digital Audio Resampling Home Page Center for
Computer Research in Music and Acoustics (CCRMA), Stanford
University, 2015-02-23. Web published at
http://ccrma.stanford.edu/~jos/resample/.

%prep
%setup -q -n resampy-%{version}
# Remove shebang from files
sed -i -e '/^#!\//, 1d' */*.py
# Remove code coverage options
sed -i '/addopts/d' setup.cfg

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/resampy
%{python_sitelib}/resampy-%{version}.dist-info
%endif

%changelog
* Mon Sep 23 2024 Ben Greiner <code@bnavigator.de>
- Switch to testing in multibuild: The obs runtime requirement
  resolver deals with numba/numpy blockage more gracefully than
  trying to resolve a BuildRequires on them. Numba 0.60 is
  restricted to Numpy < 2.1 right now.
  * Update requirements
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.4.3:
  * Update to remove deprecated usage of pkg_resources
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- reenable build for python311 (numba available)
* Sat Apr  1 2023 Ben Greiner <code@bnavigator.de>
- Skip building for python311: no numba yet
* Mon Nov 14 2022 pgajdos@suse.com
- version update to 0.4.2
  v0.4.2
  ~~~~~~
  * Fixed buffer length calculation to avoid
    numerical overflow issues on some platforms.
  v0.4.1
  ~~~~~~
  * Fixed a rounding error in output buffer length calculations.
  * Added a special case to disable unsupported parallel mode on 32bit architectures.
  v0.4.0
  ~~~~~~
  * Reduced import time and switched to parallel=False by default.
  * Integer-valued inputs now produce floating point outputs.
  v0.3.1
  ~~~~~~
  * Fixed an efficiency regression introduced in the 0.3.0 release.
  v0.3.0
  ~~~~~~
  * Enable caching of pre-computed filters to improve runtime efficiency.
  * Automate pre-computed filter generation.  Regenerated and improved `kaiser_fast` and `kaiser_best` filters.
  * Improved documentation
  * Enable parallel processing for sample rate conversion. *Antonio Valentino*
  * Improved python packaging workflow.
  * Fixed a bug in resampling high-dimensional data.
  * Removed support for python 2.7.
  * Bypass sample rate conversion if input and output rates are identical.
  * Added continuous integration tests for linting.
  * Non-uniform output sample positions. *Antonio Valentio*
* Fri Apr 23 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build: No NumPy for python36 in TW (NEP 29)
- Enable test suite with GitHub archive
* Thu Apr  9 2020 Todd R <toddrme2178@gmail.com>
- Temporarily add skip_python2 to allow other packages to build.
* Sat Aug 31 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more specific in %%files section
  * removed python devel
- update to version 0.2.2:
  * #68 Preserve array ordering (C- or F-contiguity) from input to
    output.
* Fri Nov  2 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Fri Nov  2 2018 Todd R <toddrme2178@gmail.com>
- Initial version
